@@ -183,6 +183,11 @@ class PythonFunction(PythonPythonMapper):
 
         :type: list(str)
         """
+        self.overloads = obj["overloads"]
+        """The list of overloaded signatures ``[(args, return_annotation), ...]`` of this function.
+
+        :type: list(tuple(str, str))
+        """
 
 
 class PythonMethod(PythonFunction):
